"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6.QtWidgets import *


class QUndoView(QListView):
    """
    https://doc.qt.io/qt-6/qundoview.html

    **Detailed Description**

    QUndoView is a **QListView**  which displays the list of commands pushed on
    an undo stack. The most recently executed command is always selected.
    Selecting a different command results in a call to **QUndoStack::setIndex**
    (), rolling the state of the document backwards or forward to the new
    command.

    The stack can be set explicitly with **setStack** (). Alternatively, a
    **QUndoGroup**  object can be set with **setGroup** (). The view will then
    update itself automatically whenever the active stack of the group changes.

    ![](images/qundoview.png)
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qundoview.html#QUndoView

        **QUndoView::QUndoView(QWidget * parent = nullptr)**

        Constructs a new view with parent **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, stack: QtGui.QUndoStack, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qundoview.html#QUndoView-1

        **QUndoView::QUndoView(QUndoStack * stack , QWidget * parent =
        nullptr)**

        Constructs a new view with parent **parent** and sets the observed stack
        to **stack**.
        """
        ...

    @typing.overload
    def __init__(
        self, group: QtGui.QUndoGroup, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qundoview.html#QUndoView-2

        **QUndoView::QUndoView(QUndoGroup * group , QWidget * parent =
        nullptr)**

        Constructs a new view with parent **parent** and sets the observed group
        to **group**.

        The view will update itself autmiatically whenever the active stack of
        the group changes.
        """
        ...

    def setGroup(self, group: QtGui.QUndoGroup) -> None:
        """
        https://doc.qt.io/qt-6/qundoview.html#setGroup

        **[slot] void QUndoView::setGroup(QUndoGroup * group )**

        Sets the group displayed by this view to **group**. If **group** is
        `nullptr`, the view will be empty.

        The view will update itself automatically whenever the active stack of
        the group changes.

        **See also** **group** () and **setStack** ().
        """
        ...

    def setStack(self, stack: QtGui.QUndoStack) -> None:
        """
        https://doc.qt.io/qt-6/qundoview.html#setStack

        **[slot] void QUndoView::setStack(QUndoStack * stack )**

        Sets the stack displayed by this view to **stack**. If **stack** is
        `nullptr`, the view will be empty.

        If the view was previously looking at a **QUndoGroup** , the group is
        set to `nullptr`.

        **See also** **stack** () and **setGroup** ().
        """
        ...

    def cleanIcon(self) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qundoview.html#cleanIcon-prop

        **cleanIcon : QIcon**

        This property holds the icon used to represent the clean state.

        A stack may have a clean state set with **QUndoStack::setClean** ().
        This is usually the state of the document at the point it was saved.
        **QUndoView**  can display an icon in the list of commands to show the
        clean state. If this property is a null icon, no icon is shown. The
        default value is the null icon.

        **Access functions:**

        QIcon **cleanIcon** () const
        void **setCleanIcon** (const QIcon &
        **icon** )
        """
        ...

    def setCleanIcon(self, icon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qundoview.html#cleanIcon-prop

        **cleanIcon : QIcon**

        This property holds the icon used to represent the clean state.

        A stack may have a clean state set with **QUndoStack::setClean** ().
        This is usually the state of the document at the point it was saved.
        **QUndoView**  can display an icon in the list of commands to show the
        clean state. If this property is a null icon, no icon is shown. The
        default value is the null icon.

        **Access functions:**

        QIcon **cleanIcon** () const
        void **setCleanIcon** (const QIcon &
        **icon** )
        """
        ...

    def emptyLabel(self) -> str:
        """
        https://doc.qt.io/qt-6/qundoview.html#emptyLabel-prop

        **emptyLabel : QString**

        This property holds the label used for the empty state.

        The empty label is the topmost element in the list of commands, which
        represents the state of the document before any commands were pushed on
        the stack. The default is the string "<empty>".

        **Access functions:**

        QString **emptyLabel** () const
        void **setEmptyLabel** (const QString
        & **label** )

        **Member Function Documentation**
        """
        ...

    def setEmptyLabel(self, label: str) -> None:
        """
        https://doc.qt.io/qt-6/qundoview.html#emptyLabel-prop

        **emptyLabel : QString**

        This property holds the label used for the empty state.

        The empty label is the topmost element in the list of commands, which
        represents the state of the document before any commands were pushed on
        the stack. The default is the string "<empty>".

        **Access functions:**

        QString **emptyLabel** () const
        void **setEmptyLabel** (const QString
        & **label** )

        **Member Function Documentation**
        """
        ...

    def group(self) -> QtGui.QUndoGroup:
        """
        https://doc.qt.io/qt-6/qundoview.html#group

        **QUndoGroup *QUndoView::group() const**

        Returns the group displayed by this view.

        If the view is not looking at group, this function returns `nullptr`.

        **See also** **setGroup** () and **setStack** ().
        """
        ...

    def stack(self) -> QtGui.QUndoStack:
        """
        https://doc.qt.io/qt-6/qundoview.html#stack

        **QUndoStack *QUndoView::stack() const**

        Returns the stack currently displayed by this view. If the view is
        looking at a **QUndoGroup** , this the group's active stack.

        **See also** **setStack** () and **setGroup** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QMetaObject(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmetaobject.html

    **Detailed Description**

    The Qt **Meta-Object System**  in Qt is responsible for the signals and
    slots inter-object communication mechanism, runtime type information, and
    the Qt property system. A single QMetaObject instance is created for each
    **QObject**  subclass that is used in an application, and this instance
    stores all the meta-information for the **QObject**  subclass. This object
    is available as **QObject::metaObject** ().

    This class is not normally required for application programming, but it is
    useful if you write meta-applications, such as scripting engines or GUI
    builders.

    The functions you are most likely to find useful are these:

    * **className** () returns the name of a class.
      * **superClass** ()
    returns the superclass's meta-object.
      * **method** () and **methodCount**
    () provide information about a class's meta-methods (signals, slots and
    other **invokable**  member functions).
      * **enumerator** () and
    **enumeratorCount** () and provide information about a class's enumerators.
    * **propertyCount** () and **property** () provide information about a
    class's properties.
      * **constructor** () and **constructorCount** ()
    provide information about a class's meta-constructors.

    The index functions **indexOfConstructor** (), **indexOfMethod** (),
    **indexOfEnumerator** (), and **indexOfProperty** () map names of
    constructors, member functions, enumerators, or properties to indexes in the
    meta-object. For example, Qt uses **indexOfMethod** () internally when you
    connect a signal to a slot.

    Classes can also have a list of **name** \\-- **value** pairs of additional
    class information, stored in **QMetaClassInfo**  objects. The number of
    pairs is returned by **classInfoCount** (), single pairs are returned by
    **classInfo** (), and you can search for pairs with **indexOfClassInfo** ().

    **Note:** Operations that use the meta object system are generally thread-
    safe, as QMetaObjects are typically static read-only instances generated at
    compile time. However, if meta objects are dynamically modified by the
    application (for instance, when using **QQmlPropertyMap** ), then the
    application has to explicitly synchronize access to the respective meta
    object.

    **See also** **QMetaClassInfo** , **QMetaEnum** , **QMetaMethod** ,
    **QMetaProperty** , **QMetaType** , and **Meta-Object System** .
    """

    class Connection(PyQt6.sip.simplewrapper):
        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, other: "QMetaObject.Connection") -> None:
            ...

        def swap(self, o: "QMetaObject.Connection") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QMetaObject") -> None:
        ...

    def inherits(self, metaObject: "QMetaObject") -> bool:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#inherits

        **[since 5.7] bool QMetaObject::inherits(const QMetaObject * metaObject
        ) const**

        Returns `true` if the class described by this **QMetaObject**  inherits
        the type described by **metaObject** ; otherwise returns false.

        A type is considered to inherit itself.

        This function was introduced in Qt 5.7.
        """
        ...

    def constructor(self, index: int) -> QMetaMethod:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#constructor

        **QMetaMethod QMetaObject::constructor(int index ) const**

        Returns the meta-data for the constructor with the given **index**.

        **See also** **constructorCount** () and **newInstance** ().
        """
        ...

    def indexOfConstructor(self, constructor: str) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#indexOfConstructor

        **int QMetaObject::indexOfConstructor(const char * constructor ) const**

        Finds **constructor** and returns its index; otherwise returns -1.

        Note that the **constructor** has to be in normalized form, as returned
        by **normalizedSignature** ().

        **See also** **constructor** (), **constructorCount** (), and
        **normalizedSignature** ().
        """
        ...

    def constructorCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#constructorCount

        **int QMetaObject::constructorCount() const**

        Returns the number of constructors in this class.

        **See also** **constructor** () and **indexOfConstructor** ().
        """
        ...

    @typing.overload
    @staticmethod
    def invokeMethod(
        obj: QObject,
        member: str,
        a2: Qt.ConnectionType,
        ret: "QGenericReturnArgument",
        value0: "QGenericArgument" = ...,
        value1: "QGenericArgument" = ...,
        value2: "QGenericArgument" = ...,
        value3: "QGenericArgument" = ...,
        value4: "QGenericArgument" = ...,
        value5: "QGenericArgument" = ...,
        value6: "QGenericArgument" = ...,
        value7: "QGenericArgument" = ...,
        value8: "QGenericArgument" = ...,
        value9: "QGenericArgument" = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#invokeMethod

        **[static] bool QMetaObject::invokeMethod(QObject * obj , const char *
        member , Qt::ConnectionType type , QGenericReturnArgument ret ,
        QGenericArgument val0 = QGenericArgument(nullptr), QGenericArgument val1
        = QGenericArgument(), QGenericArgument val2 = QGenericArgument(),
        QGenericArgument val3 = QGenericArgument(), QGenericArgument val4 =
        QGenericArgument(), QGenericArgument val5 = QGenericArgument(),
        QGenericArgument val6 = QGenericArgument(), QGenericArgument val7 =
        QGenericArgument(), QGenericArgument val8 = QGenericArgument(),
        QGenericArgument val9 = QGenericArgument())**

        Invokes the **member** (a signal or a slot name) on the object **obj**.
        Returns `true` if the member could be invoked. Returns `false` if there
        is no such member or the parameters did not match.

        The invocation can be either synchronous or asynchronous, depending on
        **type** :

        * If **type** is **Qt::DirectConnection** , the member will be invoked
        immediately.
          * If **type** is **Qt::QueuedConnection** , a **QEvent**
        will be sent and the member is invoked as soon as the application enters
        the main event loop.
          * If **type** is **Qt::BlockingQueuedConnection**
        , the method will be invoked in the same way as for
        **Qt::QueuedConnection** , except that the current thread will block
        until the event is delivered. Using this connection type to communicate
        between objects in the same thread will lead to deadlocks.
          * If
        **type** is **Qt::AutoConnection** , the member is invoked synchronously
        if **obj** lives in the same thread as the caller; otherwise it will
        invoke the member asynchronously.

        The return value of the **member** function call is placed in **ret**.
        If the invocation is asynchronous, the return value cannot be evaluated.
        You can pass up to ten arguments ( **val0** , **val1** , **val2** ,
        **val3** , **val4** , **val5** , **val6** , **val7** , **val8** , and
        **val9** ) to the **member** function.

        **QGenericArgument**  and **QGenericReturnArgument**  are internal
        helper classes. Because signals and slots can be dynamically invoked,
        you must enclose the arguments using the **Q_ARG** () and
        **Q_RETURN_ARG** () macros. **Q_ARG** () takes a type name and a const
        reference of that type; **Q_RETURN_ARG** () takes a type name and a non-
        const reference.

        You only need to pass the name of the signal or slot to this function,
        not the entire signature. For example, to asynchronously invoke the
        **quit** () slot on a **QThread** , use the following code:

        **QMetaObject** ::invokeMethod(thread, "quit",
        Qt::QueuedConnection);

        With asynchronous method invocations, the parameters must be of types
        that are known to Qt's meta-object system, because Qt needs to copy the
        arguments to store them in an event behind the scenes. If you try to use
        a queued connection and get the error message

        **QMetaObject** ::invokeMethod: Unable to handle unregistered datatype
        'MyType'

        call **qRegisterMetaType** () to register the data type before you call
        invokeMethod().

        To synchronously invoke the `compute(QString, int, double)` slot on some
        arbitrary object `obj` retrieve its return value:

        **QString**  retVal;
            **QMetaObject** ::invokeMethod(obj, "compute",
        Qt::DirectConnection,
        Q_RETURN_ARG(**QString** , retVal),
        Q_ARG(**QString** , "sqrt"),
                                      Q_ARG(int,
        42),
                                      Q_ARG(double, 9.7));

        If the "compute" slot does not take exactly one **QString** , one int
        and one double in the specified order, the call will fail.

        **Note:** This function is **thread-safe** .

        **See also** **Q_ARG** (), **Q_RETURN_ARG** (), **qRegisterMetaType**
        (), and **QMetaMethod::invoke** ().
        """
        ...

    @typing.overload
    @staticmethod
    def invokeMethod(
        obj: QObject,
        member: str,
        ret: "QGenericReturnArgument",
        value0: "QGenericArgument" = ...,
        value1: "QGenericArgument" = ...,
        value2: "QGenericArgument" = ...,
        value3: "QGenericArgument" = ...,
        value4: "QGenericArgument" = ...,
        value5: "QGenericArgument" = ...,
        value6: "QGenericArgument" = ...,
        value7: "QGenericArgument" = ...,
        value8: "QGenericArgument" = ...,
        value9: "QGenericArgument" = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#invokeMethod-1

        **[static] bool QMetaObject::invokeMethod(QObject * obj , const char *
        member , QGenericReturnArgument ret , QGenericArgument val0 =
        QGenericArgument(0), QGenericArgument val1 = QGenericArgument(),
        QGenericArgument val2 = QGenericArgument(), QGenericArgument val3 =
        QGenericArgument(), QGenericArgument val4 = QGenericArgument(),
        QGenericArgument val5 = QGenericArgument(), QGenericArgument val6 =
        QGenericArgument(), QGenericArgument val7 = QGenericArgument(),
        QGenericArgument val8 = QGenericArgument(), QGenericArgument val9 =
        QGenericArgument())**

        This function overloads invokeMethod().

        This overload always invokes the member using the connection type
        **Qt::AutoConnection** .

        **Note:** This function is **thread-safe** .
        """
        ...

    @typing.overload
    @staticmethod
    def invokeMethod(
        obj: QObject,
        member: str,
        type: Qt.ConnectionType,
        value0: "QGenericArgument" = ...,
        value1: "QGenericArgument" = ...,
        value2: "QGenericArgument" = ...,
        value3: "QGenericArgument" = ...,
        value4: "QGenericArgument" = ...,
        value5: "QGenericArgument" = ...,
        value6: "QGenericArgument" = ...,
        value7: "QGenericArgument" = ...,
        value8: "QGenericArgument" = ...,
        value9: "QGenericArgument" = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#invokeMethod-2

        **[static] bool QMetaObject::invokeMethod(QObject * obj , const char *
        member , Qt::ConnectionType type , QGenericArgument val0 =
        QGenericArgument(0), QGenericArgument val1 = QGenericArgument(),
        QGenericArgument val2 = QGenericArgument(), QGenericArgument val3 =
        QGenericArgument(), QGenericArgument val4 = QGenericArgument(),
        QGenericArgument val5 = QGenericArgument(), QGenericArgument val6 =
        QGenericArgument(), QGenericArgument val7 = QGenericArgument(),
        QGenericArgument val8 = QGenericArgument(), QGenericArgument val9 =
        QGenericArgument())**

        This function overloads invokeMethod().

        This overload can be used if the return value of the member is of no
        interest.

        **Note:** This function is **thread-safe** .
        """
        ...

    @typing.overload
    @staticmethod
    def invokeMethod(
        obj: QObject,
        member: str,
        value0: "QGenericArgument" = ...,
        value1: "QGenericArgument" = ...,
        value2: "QGenericArgument" = ...,
        value3: "QGenericArgument" = ...,
        value4: "QGenericArgument" = ...,
        value5: "QGenericArgument" = ...,
        value6: "QGenericArgument" = ...,
        value7: "QGenericArgument" = ...,
        value8: "QGenericArgument" = ...,
        value9: "QGenericArgument" = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#invokeMethod-3

        **[static] bool QMetaObject::invokeMethod(QObject * obj , const char *
        member , QGenericArgument val0 = QGenericArgument(0), QGenericArgument
        val1 = QGenericArgument(), QGenericArgument val2 = QGenericArgument(),
        QGenericArgument val3 = QGenericArgument(), QGenericArgument val4 =
        QGenericArgument(), QGenericArgument val5 = QGenericArgument(),
        QGenericArgument val6 = QGenericArgument(), QGenericArgument val7 =
        QGenericArgument(), QGenericArgument val8 = QGenericArgument(),
        QGenericArgument val9 = QGenericArgument())**

        This function overloads invokeMethod().

        This overload invokes the member using the connection type
        **Qt::AutoConnection**  and ignores return values.

        **Note:** This function is **thread-safe** .
        """
        ...

    @staticmethod
    def normalizedType(type: str) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#normalizedType

        **[static] QByteArray QMetaObject::normalizedType(const char * type )**

        Normalizes a **type**.

        See **QMetaObject::normalizedSignature** () for a description on how Qt
        normalizes.

        Example:

        **QByteArray**  normType = **QMetaObject** ::normalizedType(" int
        const  *");
            // normType is now "const int*"

        **See also** **normalizedSignature** ().
        """
        ...

    @staticmethod
    def normalizedSignature(method: str) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#normalizedSignature

        **[static] QByteArray QMetaObject::normalizedSignature(const char *
        method )**

        Normalizes the signature of the given **method**.

        Qt uses normalized signatures to decide whether two given signals and
        slots are compatible. Normalization reduces whitespace to a minimum,
        moves 'const' to the front where appropriate, removes 'const' from value
        types and replaces const references with values.

        **See also** **checkConnectArgs** () and **normalizedType** ().
        """
        ...

    @staticmethod
    def connectSlotsByName(o: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#connectSlotsByName

        **[static] void QMetaObject::connectSlotsByName(QObject * object )**

        Searches recursively for all child objects of the given **object** , and
        connects matching signals from them to slots of **object** that follow
        the following form:

        void on_<object name>_<signal name>(<signal parameters>);

        Let's assume our object has a child object of type `QPushButton` with
        the **object name**  `button1`. The slot to catch the button's
        `clicked()` signal would be:

        void on_button1_clicked();

        If **object** itself has a properly set object name, its own signals are
        also connected to its respective slots.

        **See also** **QObject::setObjectName** ().
        """
        ...

    @typing.overload
    @staticmethod
    def checkConnectArgs(signal: str, method: str) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#checkConnectArgs

        **[static] bool QMetaObject::checkConnectArgs(const char * signal ,
        const char * method )**

        Returns `true` if the **signal** and **method** arguments are
        compatible; otherwise returns `false`.

        Both **signal** and **method** are expected to be normalized.

        **See also** **normalizedSignature** ().
        """
        ...

    @typing.overload
    @staticmethod
    def checkConnectArgs(signal: QMetaMethod, method: QMetaMethod) -> bool:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#checkConnectArgs-1

        **[static, since 5.0] bool QMetaObject::checkConnectArgs(const
        QMetaMethod & signal , const QMetaMethod & method )**

        This is an overloaded function.

        Returns `true` if the **signal** and **method** arguments are
        compatible; otherwise returns `false`.

        This function was introduced in Qt 5.0.
        """
        ...

    def classInfo(self, index: int) -> QMetaClassInfo:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#classInfo

        **QMetaClassInfo QMetaObject::classInfo(int index ) const**

        Returns the meta-data for the item of class information with the given
        **index**.

        Example:

        class MyClass : public **QObject**
            {
                Q_OBJECT
        Q_CLASSINFO("author", "Sabrina Schweinsteiger")
        Q_CLASSINFO("url", "http://doc.moosesoft.co.uk/1.0/")

            public:
        ...
            };

        **See also** **classInfoCount** (), **classInfoOffset** (), and
        **indexOfClassInfo** ().
        """
        ...

    def property(self, index: int) -> QMetaProperty:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#property

        **QMetaProperty QMetaObject::property(int index ) const**

        Returns the meta-data for the property with the given **index**. If no
        such property exists, a null **QMetaProperty**  is returned.

        **See also** **propertyCount** (), **propertyOffset** (), and
        **indexOfProperty** ().
        """
        ...

    def enumerator(self, index: int) -> QMetaEnum:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#enumerator

        **QMetaEnum QMetaObject::enumerator(int index ) const**

        Returns the meta-data for the enumerator with the given **index**.

        **See also** **enumeratorCount** (), **enumeratorOffset** (), and
        **indexOfEnumerator** ().
        """
        ...

    def method(self, index: int) -> QMetaMethod:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#method

        **QMetaMethod QMetaObject::method(int index ) const**

        Returns the meta-data for the method with the given **index**.

        **See also** **methodCount** (), **methodOffset** (), and
        **indexOfMethod** ().
        """
        ...

    def indexOfClassInfo(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#indexOfClassInfo

        **int QMetaObject::indexOfClassInfo(const char * name ) const**

        Finds class information item **name** and returns its index; otherwise
        returns -1.

        **See also** **classInfo** (), **classInfoCount** (), and
        **classInfoOffset** ().
        """
        ...

    def indexOfProperty(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#indexOfProperty

        **int QMetaObject::indexOfProperty(const char * name ) const**

        Finds property **name** and returns its index; otherwise returns -1.

        **See also** **property** (), **propertyCount** (), and
        **propertyOffset** ().
        """
        ...

    def indexOfEnumerator(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#indexOfEnumerator

        **int QMetaObject::indexOfEnumerator(const char * name ) const**

        Finds enumerator **name** and returns its index; otherwise returns -1.

        **See also** **enumerator** (), **enumeratorCount** (), and
        **enumeratorOffset** ().
        """
        ...

    def indexOfSlot(self, slot: str) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#indexOfSlot

        **int QMetaObject::indexOfSlot(const char * slot ) const**

        Finds **slot** and returns its index; otherwise returns -1.

        This is the same as **indexOfMethod** (), except that it will return -1
        if the method exists but isn't a slot.

        **See also** **indexOfMethod** (), **method** (), **methodCount** (),
        and **methodOffset** ().
        """
        ...

    def indexOfSignal(self, signal: str) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#indexOfSignal

        **int QMetaObject::indexOfSignal(const char * signal ) const**

        Finds **signal** and returns its index; otherwise returns -1.

        This is the same as **indexOfMethod** (), except that it will return -1
        if the method exists but isn't a signal.

        Note that the **signal** has to be in normalized form, as returned by
        **normalizedSignature** ().

        **See also** **indexOfMethod** (), **normalizedSignature** (),
        **method** (), **methodCount** (), and **methodOffset** ().
        """
        ...

    def indexOfMethod(self, method: str) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#indexOfMethod

        **int QMetaObject::indexOfMethod(const char * method ) const**

        Finds **method** and returns its index; otherwise returns -1.

        Note that the **method** has to be in normalized form, as returned by
        **normalizedSignature** ().

        **See also** **method** (), **methodCount** (), **methodOffset** (), and
        **normalizedSignature** ().
        """
        ...

    def classInfoCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#classInfoCount

        **int QMetaObject::classInfoCount() const**

        Returns the number of items of class information in this class.

        **See also** **classInfo** (), **classInfoOffset** (), and
        **indexOfClassInfo** ().
        """
        ...

    def propertyCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#propertyCount

        **int QMetaObject::propertyCount() const**

        Returns the number of properties in this class, including the number of
        properties provided by each base class.

        Use code like the following to obtain a **QStringList**  containing the
        properties specific to a given class:

        const **QMetaObject** * metaObject = obj->metaObject();
        **QStringList**  properties;
            for(int i =
        metaObject->propertyOffset(); i < metaObject->propertyCount(); ++i)
        properties << **QString** ::fromLatin1(metaObject->property(i).name());

        **See also** **property** (), **propertyOffset** (), and
        **indexOfProperty** ().
        """
        ...

    def enumeratorCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#enumeratorCount

        **int QMetaObject::enumeratorCount() const**

        Returns the number of enumerators in this class.

        **See also** **enumerator** (), **enumeratorOffset** (), and
        **indexOfEnumerator** ().
        """
        ...

    def methodCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#methodCount

        **int QMetaObject::methodCount() const**

        Returns the number of methods in this class, including the number of
        methods provided by each base class. These include signals and slots as
        well as normal member functions.

        Use code like the following to obtain a **QStringList**  containing the
        methods specific to a given class:

        const **QMetaObject** * metaObject = obj->metaObject();
        **QStringList**  methods;
            for(int i = metaObject->methodOffset(); i
        < metaObject->methodCount(); ++i)
                methods << **QString**
        ::fromLatin1(metaObject->method(i).methodSignature());

        **See also** **method** (), **methodOffset** (), and **indexOfMethod**
        ().
        """
        ...

    def classInfoOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#classInfoOffset

        **int QMetaObject::classInfoOffset() const**

        Returns the class information offset for this class; i.e. the index
        position of this class's first class information item.

        If the class has no superclasses with class information, the offset is
        0; otherwise the offset is the sum of all the class information items in
        the class's superclasses.

        **See also** **classInfo** (), **classInfoCount** (), and
        **indexOfClassInfo** ().
        """
        ...

    def propertyOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#propertyOffset

        **int QMetaObject::propertyOffset() const**

        Returns the property offset for this class; i.e. the index position of
        this class's first property.

        The offset is the sum of all the properties in the class's superclasses
        (which is always positive since **QObject**  has the name() property).

        **See also** **property** (), **propertyCount** (), and
        **indexOfProperty** ().
        """
        ...

    def enumeratorOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#enumeratorOffset

        **int QMetaObject::enumeratorOffset() const**

        Returns the enumerator offset for this class; i.e. the index position of
        this class's first enumerator.

        If the class has no superclasses with enumerators, the offset is 0;
        otherwise the offset is the sum of all the enumerators in the class's
        superclasses.

        **See also** **enumerator** (), **enumeratorCount** (), and
        **indexOfEnumerator** ().
        """
        ...

    def methodOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#methodOffset

        **int QMetaObject::methodOffset() const**

        Returns the method offset for this class; i.e. the index position of
        this class's first member function.

        The offset is the sum of all the methods in the class's superclasses
        (which is always positive since **QObject**  has the deleteLater() slot
        and a destroyed() signal).

        **See also** **method** (), **methodCount** (), and **indexOfMethod**
        ().
        """
        ...

    def userProperty(self) -> QMetaProperty:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#userProperty

        **QMetaProperty QMetaObject::userProperty() const**

        Returns the property that has the `USER` flag set to true.

        **See also** **QMetaProperty::isUser** ().
        """
        ...

    def superClass(self) -> "QMetaObject":
        """
        https://doc.qt.io/qt-6/qmetaobject.html#superClass

        **const QMetaObject *QMetaObject::superClass() const**

        Returns the meta-object of the superclass, or `nullptr` if there is no
        such object.

        **See also** **className** ().
        """
        ...

    def className(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#className

        **const char *QMetaObject::className() const**

        Returns the class name.

        **See also** **superClass** ().
        """
        ...

    def metaType(self) -> QMetaType:
        """
        https://doc.qt.io/qt-6/qmetaobject.html#metaType

        **[since 6.2] QMetaType QMetaObject::metaType() const**

        Returns the metatype corresponding to this metaobject. If the metaobject
        originates from a namespace, an invalid metatype is returned.

        This function was introduced in Qt 6.2.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtHelp import *


class QHelpEngineCore(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qhelpenginecore.html

    **Detailed Description**

    Before the help engine can be used, it must be initialized by calling
    **setupData** (). At the beginning of the setup process the signal
    **setupStarted** () is emitted. From this point on until the signal
    **setupFinished** () is emitted, is the help data in an undefined meaning
    unusable state.

    The core help engine can be used to perform different tasks. By calling
    **documentsForIdentifier** () the engine returns URLs specifying the file
    locations inside the help system. The actual file data can then be retrived
    by calling **fileData** ().

    The help engine can contain any number of custom filters. The management of
    the filters, including adding new filters, changing filter definitions, or
    removing existing filters, is done through the **QHelpFilterEngine**  class,
    which can be accessed by the **filterEngine** () method.

    **Note:****QHelpFilterEngine**  replaces the older filter API that is
    deprecated since Qt 5.13. Call **setUsesFilterEngine** () with `true` to
    enable the new functionality.

    The core help engine has two modes:

    * Read-only mode, where the help collection file is not changed unless
    explicitly requested. This also works if the collection file is in a read-
    only location, and is the default.
      * Fully writable mode, which requires
    the help collection file to be writable.

    The mode can be changed by calling **setReadOnly** () method, prior to
    calling **setupData** ().

    The help engine also offers the possibility to set and read values in a
    persistent way comparable to ini files or Windows registry entries. For more
    information see setValue() or value().

    This class does not offer any GUI components or functionality for indices or
    contents. If you need one of those use **QHelpEngine**  instead.
    """

    def __init__(
        self, collectionFile: str, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#QHelpEngineCore

        **QHelpEngineCore::QHelpEngineCore(const QString & collectionFile ,
        QObject * parent = nullptr)**

        Constructs a new core help engine with a **parent**. The help engine
        uses the information stored in the **collectionFile** to provide help.
        If the collection file does not exist yet, it'll be created.
        """
        ...

    def setReadOnly(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#readOnly-prop

        **[since 6.0] readOnly : bool**

        This property holds whether the help engine is read-only.

        In read-only mode, the user can use the help engine with a collection
        file installed in a read-only location. In this case, some functionality
        won't be accessible, like registering additional documentation, filter
        editing, or any action that would require changes to the collection
        file. Setting it to `false` enables the full functionality of the help
        engine.

        By default, this property is `true`.

        This property was introduced in Qt 6.0.

        **Access functions:**

        bool **isReadOnly** () const
        void **setReadOnly** (bool **enable** )

        **Member Function Documentation**
        """
        ...

    def isReadOnly(self) -> bool:
        ...

    @typing.overload
    def documentsForKeyword(self, keyword: str) -> typing.List["QHelpLink"]:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#documentsForKeyword

        **[since 5.15] QList<QHelpLink>
        QHelpEngineCore::documentsForKeyword(const QString & keyword ) const**

        Returns a list of all the document links found for the **keyword**. The
        returned list contents depend on the current filter, and therefore only
        the keywords registered for the current filter will be returned.

        This function was introduced in Qt 5.15.
        """
        ...

    @typing.overload
    def documentsForKeyword(
        self, keyword: str, filterName: str
    ) -> typing.List["QHelpLink"]:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#documentsForKeyword-1

        **[since 5.15] QList<QHelpLink>
        QHelpEngineCore::documentsForKeyword(const QString & keyword , const
        QString & filterName ) const**

        Returns a list of the document links found for the **keyword** ,
        filtered by **filterName**. The returned list contents depend on the
        passed filter, and therefore only the keywords registered for this
        filter will be returned. If you want to get all results unfiltered, pass
        empty string as **filterName**.

        This function was introduced in Qt 5.15.
        """
        ...

    @typing.overload
    def documentsForIdentifier(self, id: str) -> typing.List["QHelpLink"]:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#documentsForIdentifier

        **[since 5.15] QList<QHelpLink>
        QHelpEngineCore::documentsForIdentifier(const QString & id ) const**

        Returns a list of all the document links found for the **id**. The
        returned list contents depend on the current filter, and therefore only
        the keywords registered for the current filter will be returned.

        This function was introduced in Qt 5.15.
        """
        ...

    @typing.overload
    def documentsForIdentifier(
        self, id: str, filterName: str
    ) -> typing.List["QHelpLink"]:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#documentsForIdentifier-1

        **[since 5.15] QList<QHelpLink>
        QHelpEngineCore::documentsForIdentifier(const QString & id , const
        QString & filterName ) const**

        Returns a list of the document links found for the **id** , filtered by
        **filterName**. The returned list contents depend on the passed filter,
        and therefore only the keywords registered for this filter will be
        returned. If you want to get all results unfiltered, pass empty string
        as **filterName**.

        This function was introduced in Qt 5.15.
        """
        ...

    def usesFilterEngine(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#usesFilterEngine

        **[since 5.13] bool QHelpEngineCore::usesFilterEngine() const**

        Returns whether the help engine uses the new filter functionality.

        This function was introduced in Qt 5.13.

        **See also** **setUsesFilterEngine** () and **filterEngine** ().
        """
        ...

    def setUsesFilterEngine(self, uses: bool) -> None:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#setUsesFilterEngine

        **[since 5.13] void QHelpEngineCore::setUsesFilterEngine(bool uses )**

        Enables or disables the new filter engine functionality inside the help
        engine, according to the passed **uses** parameter.

        This function was introduced in Qt 5.13.

        **See also** **usesFilterEngine** () and **filterEngine** ().
        """
        ...

    def files(
        self, namespaceName: str, filterName: str, extensionFilter: str = ...
    ) -> typing.List[QtCore.QUrl]:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#files-1

        **QList<QUrl> QHelpEngineCore::files(const QString namespaceName , const
        QString & filterName , const QString & extensionFilter = QString())**

        Returns a list of files contained in the Qt compressed help file for
        **namespaceName**. The files can be filtered by **filterName** as well
        as by their extension **extensionFilter** (for example, 'html').
        """
        ...

    def filterEngine(self) -> "QHelpFilterEngine":
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#filterEngine

        **[since 5.13] QHelpFilterEngine *QHelpEngineCore::filterEngine()
        const**

        Returns the filter engine associated with this help engine. The filter
        engine allows for adding, changing, and removing existing filters for
        this help engine. To use the engine you also have to call
        **setUsesFilterEngine** () set to `true`.

        This function was introduced in Qt 5.13.
        """
        ...

    def setAutoSaveFilter(self, save: bool) -> None:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#autoSaveFilter-prop

        **autoSaveFilter : bool**

        This property holds whether **QHelpEngineCore**  is in auto save filter
        mode or not.

        If **QHelpEngineCore**  is in auto save filter mode, the current filter
        is automatically saved when it is changed by the
        **QHelpFilterEngine::setActiveFilter** () function. The filter is saved
        persistently in the help collection file.

        By default, this mode is on.

        **Access functions:**

        bool **autoSaveFilter** () const
        void **setAutoSaveFilter** (bool
        **save** )
        """
        ...

    def autoSaveFilter(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#autoSaveFilter-prop

        **autoSaveFilter : bool**

        This property holds whether **QHelpEngineCore**  is in auto save filter
        mode or not.

        If **QHelpEngineCore**  is in auto save filter mode, the current filter
        is automatically saved when it is changed by the
        **QHelpFilterEngine::setActiveFilter** () function. The filter is saved
        persistently in the help collection file.

        By default, this mode is on.

        **Access functions:**

        bool **autoSaveFilter** () const
        void **setAutoSaveFilter** (bool
        **save** )
        """
        ...

    def error(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#error

        **QString QHelpEngineCore::error() const**

        Returns a description of the last error that occurred.
        """
        ...

    @staticmethod
    def metaData(documentationFileName: str, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#metaData

        **[static] QVariant QHelpEngineCore::metaData(const QString &
        documentationFileName , const QString & name )**

        Returns the meta data for the Qt compressed help file
        **documentationFileName**. If there is no data available for **name** ,
        an invalid QVariant() is returned. The meta data is defined when
        creating the Qt compressed help file and cannot be modified later.
        Common meta data includes e.g. the author of the documentation.
        """
        ...

    def setCustomValue(self, key: str, value: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#setCustomValue

        **bool QHelpEngineCore::setCustomValue(const QString & key , const
        QVariant & value )**

        Save the **value** under the **key**. If the key already exist, the
        value will be overwritten. Returns true if the value was saved
        successfully, otherwise false.

        **See also** **customValue** () and **removeCustomValue** ().
        """
        ...

    def customValue(self, key: str, defaultValue: typing.Any = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#customValue

        **QVariant QHelpEngineCore::customValue(const QString & key , const
        QVariant & defaultValue = QVariant()) const**

        Returns the value assigned to the **key**. If the requested key does not
        exist, the specified **defaultValue** is returned.

        **See also** **setCustomValue** () and **removeCustomValue** ().
        """
        ...

    def removeCustomValue(self, key: str) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#removeCustomValue

        **bool QHelpEngineCore::removeCustomValue(const QString & key )**

        Removes the **key** from the settings section in the collection file.
        Returns true if the value was removed successfully, otherwise false.

        **See also** **customValue** () and **setCustomValue** ().
        """
        ...

    def fileData(self, url: QtCore.QUrl) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#fileData

        **QByteArray QHelpEngineCore::fileData(const QUrl & url ) const**

        Returns the data of the file specified by **url**. If the file does not
        exist, an empty **QByteArray**  is returned.

        **See also** **findFile** ().
        """
        ...

    def findFile(self, url: QtCore.QUrl) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#findFile

        **QUrl QHelpEngineCore::findFile(const QUrl & url ) const**

        Returns the corrected URL for the **url** that may refer to a different
        namespace defined by the virtual folder defined as a part of the
        **url**. If the virtual folder matches the namespace of the **url** ,
        the method just checks if the file exists and returns the same **url**.
        When the virtual folder doesn't match the namespace of the **url** , it
        tries to find the best matching namespace according to the active
        filter. When the namespace is found, it returns the corrected URL if the
        file exists, otherwise it returns an invalid URL.
        """
        ...

    def registeredDocumentations(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#registeredDocumentations

        **QStringList QHelpEngineCore::registeredDocumentations() const**

        Returns a list of all registered Qt compressed help files of the current
        collection file. The returned names are the namespaces of the registered
        Qt compressed help files (.qch).
        """
        ...

    def documentationFileName(self, namespaceName: str) -> str:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#documentationFileName

        **QString QHelpEngineCore::documentationFileName(const QString &
        namespaceName )**

        Returns the absolute file name of the Qt compressed help file (.qch)
        identified by the **namespaceName**. If there is no Qt compressed help
        file with the specified namespace registered, an empty string is
        returned.

        **See also** **namespaceName** ().
        """
        ...

    def unregisterDocumentation(self, namespaceName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#unregisterDocumentation

        **bool QHelpEngineCore::unregisterDocumentation(const QString &
        namespaceName )**

        Unregisters the Qt compressed help file (.qch) identified by its
        **namespaceName** from the help collection. Returns true on success,
        otherwise false.

        **See also** **registerDocumentation** () and **error** ().
        """
        ...

    def registerDocumentation(self, documentationFileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#registerDocumentation

        **bool QHelpEngineCore::registerDocumentation(const QString &
        documentationFileName )**

        Registers the Qt compressed help file (.qch) contained in the file
        **documentationFileName**. One compressed help file, uniquely identified
        by its namespace can only be registered once. True is returned if the
        registration was successful, otherwise false.

        **See also** **unregisterDocumentation** () and **error** ().
        """
        ...

    @staticmethod
    def namespaceName(documentationFileName: str) -> str:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#namespaceName

        **[static] QString QHelpEngineCore::namespaceName(const QString &
        documentationFileName )**

        Returns the namespace name defined for the Qt compressed help file
        (.qch) specified by its **documentationFileName**. If the file is not
        valid, an empty string is returned.

        **See also** **documentationFileName** ().
        """
        ...

    def copyCollectionFile(self, fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#copyCollectionFile

        **bool QHelpEngineCore::copyCollectionFile(const QString & fileName )**

        Creates the file **fileName** and copies all contents from the current
        collection file into the newly created file, and returns true if
        successful; otherwise returns false.

        The copying process makes sure that file references to Qt Collection
        files (`.qch`) files are updated accordingly.
        """
        ...

    def setCollectionFile(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#collectionFile-prop

        **collectionFile : QString**

        This property holds the absolute file name of the collection file
        currently used.

        Setting this property leaves the help engine in an invalid state. It is
        important to invoke **setupData** () or any getter function in order to
        setup the help engine again.

        **Access functions:**

        QString **collectionFile** () const
        void **setCollectionFile** (const
        QString & **fileName** )
        """
        ...

    def collectionFile(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#collectionFile-prop

        **collectionFile : QString**

        This property holds the absolute file name of the collection file
        currently used.

        Setting this property leaves the help engine in an invalid state. It is
        important to invoke **setupData** () or any getter function in order to
        setup the help engine again.

        **Access functions:**

        QString **collectionFile** () const
        void **setCollectionFile** (const
        QString & **fileName** )
        """
        ...

    def setupData(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#setupData

        **bool QHelpEngineCore::setupData()**

        Sets up the help engine by processing the information found in the
        collection file and returns true if successful; otherwise returns false.

        By calling the function, the help engine is forced to initialize itself
        immediately. Most of the times, this function does not have to be called
        explicitly because getter functions which depend on a correctly set up
        help engine do that themselves.

        **Note:**`qsqlite4.dll` needs to be deployed with the application as the
        help system uses the sqlite driver when loading help collections.
        """
        ...

    @property
    def setupFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#setupFinished

        **[signal] void QHelpEngineCore::setupFinished()**

        This signal is emitted when the setup is complete.
        """
        ...

    @property
    def setupStarted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#setupStarted

        **[signal] void QHelpEngineCore::setupStarted()**

        This signal is emitted when setup is started.
        """
        ...

    @property
    def warning(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpenginecore.html#warning

        **[signal] void QHelpEngineCore::warning(const QString & msg )**

        This signal is emitted when a non critical error occurs. The warning
        message is stored in **msg**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6.QtNfc import *
import enum


class QNdefNfcTextRecord(QNdefRecord):
    """
    https://doc.qt.io/qt-6/qndefnfctextrecord.html

    **Detailed Description**

    RTD-Text encapsulates a user displayable text record.
    """

    class Encoding(enum.Enum):
        Utf8: QNdefNfcTextRecord = ...
        Utf16: QNdefNfcTextRecord = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#QNdefNfcTextRecord

        **QNdefNfcTextRecord::QNdefNfcTextRecord()**

        Constructs an empty NFC text record of type **QNdefRecord::NfcRtd** .
        """
        ...

    @typing.overload
    def __init__(self, other: QNdefRecord) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#QNdefNfcTextRecord-1

        **QNdefNfcTextRecord::QNdefNfcTextRecord(const QNdefRecord & other )**

        Constructs a new NFC text record that is a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QNdefNfcTextRecord") -> None:
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#QNdefNfcTextRecord

        **QNdefNfcTextRecord::QNdefNfcTextRecord()**

        Constructs an empty NFC text record of type **QNdefRecord::NfcRtd** .
        """
        ...

    def setEncoding(self, encoding: "QNdefNfcTextRecord.Encoding") -> None:
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#setEncoding

        **void QNdefNfcTextRecord::setEncoding(QNdefNfcTextRecord::Encoding
        encoding )**

        Sets the enconding of the contents to **encoding**.

        **See also** **encoding** ().
        """
        ...

    def encoding(self) -> "QNdefNfcTextRecord.Encoding":
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#encoding

        **QNdefNfcTextRecord::Encoding QNdefNfcTextRecord::encoding() const**

        Returns the encoding of the contents.

        **See also** **setEncoding** ().
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#setText

        **void QNdefNfcTextRecord::setText(const QString text )**

        Sets the contents of the text record to **text**.

        **See also** **text** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#text

        **QString QNdefNfcTextRecord::text() const**

        Returns the contents of the text record as a string.

        **See also** **setText** ().
        """
        ...

    def setLocale(self, locale: str) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#setLocale

        **void QNdefNfcTextRecord::setLocale(const QString & locale )**

        Sets the locale of the text record to **locale**.

        **See also** **locale** ().
        """
        ...

    def locale(self) -> str:
        """
        https://doc.qt.io/qt-6/qndefnfctextrecord.html#locale

        **QString QNdefNfcTextRecord::locale() const**

        Returns the locale of the text record.

        **See also** **setLocale** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
import datetime
from PyQt6.QtCore import *
import enum


class QDateTime(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdatetime.html

    **Detailed Description**

    A QDateTime object encodes a calendar date and a clock time (a "datetime").
    It combines features of the **QDate**  and **QTime**  classes. It can read
    the current datetime from the system clock. It provides functions for
    comparing datetimes and for manipulating a datetime by adding a number of
    seconds, days, months, or years.

    QDateTime can describe datetimes with respect to **local time** , to **UTC**
    , to a specified **offset from UTC**  or to a specified **time zone** , in
    conjunction with the **QTimeZone**  class. For example, a time zone of
    "Europe/Berlin" will apply the daylight-saving rules as used in Germany. In
    contrast, an offset from UTC of +3600 seconds is one hour ahead of UTC
    (usually written in ISO standard notation as "UTC+01:00"), with no daylight-
    saving offset or changes. When using either local time or a specified time
    zone, time-zone transitions such as the starts and ends of daylight-saving
    time (DST; but see below) are taken into account. The choice of system used
    to represent a datetime is described as its "timespec".

    A QDateTime object is typically created either by giving a date and time
    explicitly in the constructor, or by using a static function such as
    **currentDateTime** () or **fromMSecsSinceEpoch** (). The date and time can
    be changed with **setDate** () and **setTime** (). A datetime can also be
    set using the **setMSecsSinceEpoch** () function that takes the time, in
    milliseconds, since 00:00:00 on January 1, 1970. The **fromString** ()
    function returns a QDateTime, given a string and a date format used to
    interpret the date within the string.

    **QDateTime::currentDateTime** () returns a QDateTime that expresses the
    current time with respect to local time. **QDateTime::currentDateTimeUtc**
    () returns a QDateTime that expresses the current time with respect to UTC.

    The **date** () and **time** () functions provide access to the date and
    time parts of the datetime. The same information is provided in textual
    format by the **toString** () function.

    QDateTime provides a full set of operators to compare two QDateTime objects,
    where smaller means earlier and larger means later.

    You can increment (or decrement) a datetime by a given number of
    milliseconds using **addMSecs** (), seconds using **addSecs** (), or days
    using **addDays** (). Similarly, you can use **addMonths** () and
    **addYears** (). The **daysTo** () function returns the number of days
    between two datetimes, **secsTo** () returns the number of seconds between
    two datetimes, and **msecsTo** () returns the number of milliseconds between
    two datetimes. These operations are aware of daylight-saving time (DST) and
    other time-zone transitions, where applicable.

    Use **toTimeSpec** () to express a datetime in local time or UTC,
    **toOffsetFromUtc** () to express in terms of an offset from UTC, or
    **toTimeZone** () to express it with respect to a general time zone. You can
    use **timeSpec** () to find out what time-spec a QDateTime object stores its
    time relative to. When that is **Qt::TimeZone** , you can use **timeZone**
    () to find out which zone it is using.

    **Note:** QDateTime does not account for leap seconds.

    **Remarks**

    **Note:** All conversion to and from string formats is done using the C
    locale. For localized conversions, see **QLocale** .

    **Note:** There is no year 0 in the Gregorian calendar. Dates in that year
    are considered invalid. The year -1 is the year "1 before Christ" or "1
    before common era." The day before 1 January 1 CE is 31 December 1 BCE.

    **Range of Valid Dates**

    The range of values that QDateTime can represent is dependent on the
    internal storage implementation. QDateTime is currently stored in a qint64
    as a serial msecs value encoding the date and time. This restricts the date
    range to about +/- 292 million years, compared to the **QDate**  range of
    +/- 2 billion years. Care must be taken when creating a QDateTime with
    extreme values that you do not overflow the storage. The exact range of
    supported values varies depending on the **Qt::TimeSpec**  and time zone.

    **Use of Timezones**

    QDateTime uses the system's time zone information to determine the current
    local time zone and its offset from UTC. If the system is not configured
    correctly or not up-to-date, QDateTime will give wrong results.

    QDateTime likewise uses system-provided information to determine the offsets
    of other timezones from UTC. If this information is incomplete or out of
    date, QDateTime will give wrong results. See the **QTimeZone**
    documentation for more details.

    On modern Unix systems, this means QDateTime usually has accurate
    information about historical transitions (including DST, see below) whenever
    possible. On Windows, where the system doesn't support historical timezone
    data, historical accuracy is not maintained with respect to timezone
    transitions, notably including DST.

    **Daylight-Saving Time (DST)**

    QDateTime takes into account transitions between Standard Time and Daylight-
    Saving Time. For example, if the transition is at 2am and the clock goes
    forward to 3am, then there is a "missing" hour from 02:00:00 to 02:59:59.999
    which QDateTime considers to be invalid. Any date arithmetic performed will
    take this missing hour into account and return a valid result. For example,
    adding one minute to 01:59:59 will get 03:00:00.

    For date-times that the system `time_t` can represent (from 1901-12-14 to
    2038-01-18 on systems with 32-bit `time_t`; for the full range QDateTime can
    represent if the type is 64-bit), the standard system APIs are used to
    determine local time's offset from UTC. For date-times not handled by these
    system APIs, **QTimeZone::systemTimeZone** () is used. In either case, the
    offset information used depends on the system and may be incomplete or, for
    past times, historically inaccurate. In any case, for future dates, the
    local time zone's offsets and DST rules may change before that date comes
    around.

    **Offsets From UTC**

    There is no explicit size restriction on an offset from UTC, but there is an
    implicit limit imposed when using the **toString** () and **fromString** ()
    methods which use a [+|-]hh:mm format, effectively limiting the range to +/-
    99 hours and 59 minutes and whole minutes only. Note that currently no time
    zone has an offset outside the range of ±14 hours and all known offsets are
    multiples of five minutes.

    **See also** **QDate** , **QTime** , **QDateTimeEdit** , and **QTimeZone** .
    """

    class YearRange(enum.Enum):
        First: QDateTime = ...
        Last: QDateTime = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#QDateTime

        **QDateTime::QDateTime()**

        Constructs a null datetime.

        A null datetime is invalid, since its date and time are invalid.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, other: typing.Union["QDateTime", datetime.datetime]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#QDateTime-1

        **QDateTime::QDateTime(QDate date , QTime time , Qt::TimeSpec spec =
        Qt::LocalTime, int offsetSeconds = 0)**

        Constructs a datetime with the given **date** and **time** , using the
        time specification defined by **spec** and **offsetSeconds** seconds.

        If **date** is valid and **time** is not, the time will be set to
        midnight.

        If the **spec** is not **Qt::OffsetFromUTC**  then **offsetSeconds**
        will be ignored.

        If the **spec** is **Qt::OffsetFromUTC**  and **offsetSeconds** is 0
        then the **timeSpec** () will be set to **Qt::UTC** , i.e. an offset of
        0 seconds.

        If **spec** is **Qt::TimeZone**  then the spec will be set to
        **Qt::LocalTime** , i.e. the current system time zone. To create a
        **Qt::TimeZone**  datetime use the correct constructor.
        """
        ...

    @typing.overload
    def __init__(
        self,
        year: int,
        month: int,
        day: int,
        hour: int,
        minute: int,
        second: int = ...,
        msec: int = ...,
        timeSpec: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#QDateTime-2

        **[since 5.2] QDateTime::QDateTime(QDate date , QTime time , const
        QTimeZone & timeZone )**

        Constructs a datetime with the given **date** and **time** , using the
        Time Zone specified by **timeZone**.

        If **date** is valid and **time** is not, the time will be set to
        00:00:00.

        If **timeZone** is invalid then the datetime will be invalid.

        This function was introduced in Qt 5.2.
        """
        ...

    @typing.overload
    def __init__(
        self,
        date: typing.Union[QDate, datetime.date],
        time: typing.Union[QTime, datetime.time],
        spec: Qt.TimeSpec = ...,
        offsetSeconds: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#QDateTime-3

        **QDateTime::QDateTime(const QDateTime & other )**

        Constructs a copy of the **other** datetime.
        """
        ...

    @typing.overload
    def __init__(
        self,
        date: typing.Union[QDate, datetime.date],
        time: typing.Union[QTime, datetime.time],
        timeZone: "QTimeZone",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#QDateTime-4

        **[since 5.8] QDateTime::QDateTime(QDateTime && other )**

        Moves the content of the temporary **other** datetime to this object and
        leaves **other** in an unspecified (but proper) state.

        This function was introduced in Qt 5.8.
        """
        ...

    def setTime(self, time: typing.Union[QTime, datetime.time]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#setTime

        **void QDateTime::setTime(QTime time )**

        Sets the time part of this datetime to **time**. If **time** is not
        valid, this function sets it to midnight. Therefore, it's possible to
        clear any set time in a **QDateTime**  by setting it to a default
        **QTime** :

        **QDateTime**  dt = **QDateTime** ::currentDateTime();
        dt.setTime(**QTime** ());

        **See also** **time** (), **setDate** (), and **setTimeSpec** ().
        """
        ...

    def setDate(self, date: typing.Union[QDate, datetime.date]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#setDate

        **void QDateTime::setDate(QDate date )**

        Sets the date part of this datetime to **date**. If no time is set yet,
        it is set to midnight. If **date** is invalid, this **QDateTime**
        becomes invalid.

        **See also** **date** (), **setTime** (), and **setTimeSpec** ().
        """
        ...

    @staticmethod
    def currentSecsSinceEpoch() -> int:
        """
        https://doc.qt.io/qt-6/qdatetime.html#currentSecsSinceEpoch

        **[static, since 5.8] qint64 QDateTime::currentSecsSinceEpoch()**

        Returns the number of seconds since 1970-01-01T00:00:00 Universal
        Coordinated Time.

        This function was introduced in Qt 5.8.

        **See also** **currentMSecsSinceEpoch** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromSecsSinceEpoch(
        secs: int, spec: Qt.TimeSpec = ..., offsetSeconds: int = ...
    ) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#fromSecsSinceEpoch

        **[static, since 5.8] QDateTime QDateTime::fromSecsSinceEpoch(qint64
        secs , Qt::TimeSpec spec = Qt::LocalTime, int offsetSeconds = 0)**

        Returns a datetime whose date and time are the number of seconds
        **secs** that have passed since 1970-01-01T00:00:00.000, Coordinated
        Universal Time (**Qt::UTC** ) and converted to the given **spec**.

        Note that there are possible values for **secs** that lie outside the
        valid range of **QDateTime** , both negative and positive. The behavior
        of this function is undefined for those values.

        If the **spec** is not **Qt::OffsetFromUTC**  then the **offsetSeconds**
        will be ignored. If the **spec** is **Qt::OffsetFromUTC**  and the
        **offsetSeconds** is 0 then the spec will be set to **Qt::UTC** , i.e.
        an offset of 0 seconds.

        If **spec** is **Qt::TimeZone**  then the spec will be set to
        **Qt::LocalTime** , i.e. the current system time zone.

        This function was introduced in Qt 5.8.

        **See also** **toSecsSinceEpoch** () and **setSecsSinceEpoch** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromSecsSinceEpoch(secs: int, timeZone: "QTimeZone") -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#fromSecsSinceEpoch-1

        **[static, since 5.8] QDateTime QDateTime::fromSecsSinceEpoch(qint64
        secs , const QTimeZone & timeZone )**

        Returns a datetime whose date and time are the number of seconds
        **secs** that have passed since 1970-01-01T00:00:00.000, Coordinated
        Universal Time (**Qt::UTC** ) and with the given **timeZone**.

        This function was introduced in Qt 5.8.

        **See also** **fromMSecsSinceEpoch** ().
        """
        ...

    def setSecsSinceEpoch(self, secs: int) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#setSecsSinceEpoch

        **[since 5.8] void QDateTime::setSecsSinceEpoch(qint64 secs )**

        Sets the date and time given the number of seconds **secs** that have
        passed since 1970-01-01T00:00:00.000, Coordinated Universal Time
        (**Qt::UTC** ). On systems that do not support time zones this function
        will behave as if local time were **Qt::UTC** .

        This function was introduced in Qt 5.8.

        **See also** **toSecsSinceEpoch** () and **setMSecsSinceEpoch** ().
        """
        ...

    def toSecsSinceEpoch(self) -> int:
        """
        https://doc.qt.io/qt-6/qdatetime.html#toSecsSinceEpoch

        **[since 5.8] qint64 QDateTime::toSecsSinceEpoch() const**

        Returns the datetime as the number of seconds that have passed since
        1970-01-01T00:00:00.000, Coordinated Universal Time (**Qt::UTC** ).

        On systems that do not support time zones, this function will behave as
        if local time were **Qt::UTC** .

        The behavior for this function is undefined if the datetime stored in
        this object is not valid. However, for all valid dates, this function
        returns a unique value.

        This function was introduced in Qt 5.8.

        **See also** **toMSecsSinceEpoch** () and **setSecsSinceEpoch** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromMSecsSinceEpoch(msecs: int, timeZone: "QTimeZone") -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#fromMSecsSinceEpoch

        **[static] QDateTime QDateTime::fromMSecsSinceEpoch(qint64 msecs ,
        Qt::TimeSpec spec = Qt::LocalTime, int offsetSeconds = 0)**

        Returns a datetime whose date and time are the number of milliseconds
        **msecs** that have passed since 1970-01-01T00:00:00.000, Coordinated
        Universal Time (**Qt::UTC** ) and converted to the given **spec**.

        Note that there are possible values for **msecs** that lie outside the
        valid range of **QDateTime** , both negative and positive. The behavior
        of this function is undefined for those values.

        If the **spec** is not **Qt::OffsetFromUTC**  then the **offsetSeconds**
        will be ignored. If the **spec** is **Qt::OffsetFromUTC**  and the
        **offsetSeconds** is 0 then the spec will be set to **Qt::UTC** , i.e.
        an offset of 0 seconds.

        If **spec** is **Qt::TimeZone**  then the spec will be set to
        **Qt::LocalTime** , i.e. the current system time zone.

        **See also** **toMSecsSinceEpoch** () and **setMSecsSinceEpoch** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromMSecsSinceEpoch(
        msecs: int, spec: Qt.TimeSpec = ..., offsetSeconds: int = ...
    ) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#fromMSecsSinceEpoch-1

        **[static, since 5.2] QDateTime QDateTime::fromMSecsSinceEpoch(qint64
        msecs , const QTimeZone & timeZone )**

        Returns a datetime whose date and time are the number of milliseconds
        **msecs** that have passed since 1970-01-01T00:00:00.000, Coordinated
        Universal Time (**Qt::UTC** ) and with the given **timeZone**.

        This function was introduced in Qt 5.2.

        **See also** **fromSecsSinceEpoch** ().
        """
        ...

    def toTimeZone(self, toZone: "QTimeZone") -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#toTimeZone

        **[since 5.2] QDateTime QDateTime::toTimeZone(const QTimeZone & timeZone
        ) const**

        Returns a copy of this datetime converted to the given **timeZone**

        This function was introduced in Qt 5.2.

        **See also** **timeZone** () and **toTimeSpec** ().
        """
        ...

    def toOffsetFromUtc(self, offsetSeconds: int) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#toOffsetFromUtc

        **[since 5.2] QDateTime QDateTime::toOffsetFromUtc(int offsetSeconds )
        const**

        Returns a copy of this datetime converted to a spec of
        **Qt::OffsetFromUTC**  with the given **offsetSeconds**.

        If the **offsetSeconds** equals 0 then a UTC datetime will be returned

        This function was introduced in Qt 5.2.

        **See also** **setOffsetFromUtc** (), **offsetFromUtc** (), and
        **toTimeSpec** ().
        """
        ...

    def setTimeZone(self, toZone: "QTimeZone") -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#setTimeZone

        **[since 5.2] void QDateTime::setTimeZone(const QTimeZone & toZone )**

        Sets the time zone used in this datetime to **toZone**. The datetime
        will refer to a different point in time.

        If **toZone** is invalid then the datetime will be invalid.

        This function was introduced in Qt 5.2.

        **See also** **timeZone** () and **Qt::TimeSpec** .
        """
        ...

    def setOffsetFromUtc(self, offsetSeconds: int) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#setOffsetFromUtc

        **[since 5.2] void QDateTime::setOffsetFromUtc(int offsetSeconds )**

        Sets the **timeSpec** () to **Qt::OffsetFromUTC**  and the offset to
        **offsetSeconds**. The datetime will refer to a different point in time.

        The maximum and minimum offset is 14 positive or negative hours. If
        **offsetSeconds** is larger or smaller than that, then the result is
        undefined.

        If **offsetSeconds** is 0 then the **timeSpec** () will be set to
        **Qt::UTC** .

        This function was introduced in Qt 5.2.

        **See also** **isValid** () and **offsetFromUtc** ().
        """
        ...

    def isDaylightTime(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdatetime.html#isDaylightTime

        **[since 5.2] bool QDateTime::isDaylightTime() const**

        Returns if this datetime falls in Daylight-Saving Time.

        If the **Qt::TimeSpec**  is not **Qt::LocalTime**  or **Qt::TimeZone**
        then will always return false.

        This function was introduced in Qt 5.2.

        **See also** **timeSpec** ().
        """
        ...

    def timeZoneAbbreviation(self) -> str:
        """
        https://doc.qt.io/qt-6/qdatetime.html#timeZoneAbbreviation

        **[since 5.2] QString QDateTime::timeZoneAbbreviation() const**

        Returns the Time Zone Abbreviation for this datetime.

        The returned string depends on **timeSpec** ():

        * For **Qt::UTC**  it is "UTC".
          * For **Qt::OffsetFromUTC**  it will
        be in the format "UTC[+-]00:00".
          * For **Qt::LocalTime** , the host
        system is queried.
          * For **Qt::TimeZone** , the associated
        **QTimeZone**  object is queried.

        **Note:** The abbreviation is not guaranteed to be unique, i.e.
        different time zones may have the same abbreviation. For
        **Qt::LocalTime**  and **Qt::TimeZone** , when returned by the host
        system, the abbreviation may be localized.

        This function was introduced in Qt 5.2.

        **See also** **timeSpec** () and **QTimeZone::abbreviation** ().
        """
        ...

    def timeZone(self) -> "QTimeZone":
        """
        https://doc.qt.io/qt-6/qdatetime.html#timeZone

        **[since 5.2] QTimeZone QDateTime::timeZone() const**

        Returns the time zone of the datetime.

        If the **timeSpec** () is **Qt::LocalTime**  then an instance of the
        current system time zone will be returned. Note however that if you copy
        this time zone the instance will not remain in sync if the system time
        zone changes.

        This function was introduced in Qt 5.2.

        **See also** **setTimeZone** () and **Qt::TimeSpec** .
        """
        ...

    def offsetFromUtc(self) -> int:
        """
        https://doc.qt.io/qt-6/qdatetime.html#offsetFromUtc

        **[since 5.2] int QDateTime::offsetFromUtc() const**

        Returns this date-time's Offset From UTC in seconds.

        The result depends on **timeSpec** ():

        * `Qt::UTC` The offset is 0.
          * `Qt::OffsetFromUTC` The offset is the
        value originally set.
          * `Qt::LocalTime` The local time's offset from
        UTC is returned.
          * `Qt::TimeZone` The offset used by the time-zone is
        returned.

        For the last two, the offset at this date and time will be returned,
        taking account of Daylight-Saving Offset. The offset is the difference
        between the local time or time in the given time-zone and UTC time; it
        is positive in time-zones ahead of UTC (East of The Prime Meridian),
        negative for those behind UTC (West of The Prime Meridian).

        This function was introduced in Qt 5.2.

        **See also** **setOffsetFromUtc** ().
        """
        ...

    def swap(self, other: "QDateTime") -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#swap

        **[since 5.0] void QDateTime::swap(QDateTime & other )**

        Swaps this datetime with **other**. This operation is very fast and
        never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    @staticmethod
    def currentMSecsSinceEpoch() -> int:
        """
        https://doc.qt.io/qt-6/qdatetime.html#currentMSecsSinceEpoch

        **[static] qint64 QDateTime::currentMSecsSinceEpoch()**

        Returns the number of milliseconds since 1970-01-01T00:00:00 Universal
        Coordinated Time. This number is like the POSIX time_t variable, but
        expressed in milliseconds instead.

        **See also** **currentDateTime** (), **currentDateTimeUtc** (), and
        **toTimeSpec** ().
        """
        ...

    @staticmethod
    def currentDateTimeUtc() -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#currentDateTimeUtc

        **[static] QDateTime QDateTime::currentDateTimeUtc()**

        Returns the current datetime, as reported by the system clock, in UTC.

        **See also** **currentDateTime** (), **QDate::currentDate** (),
        **QTime::currentTime** (), and **toTimeSpec** ().
        """
        ...

    def msecsTo(self, a0: typing.Union["QDateTime", datetime.datetime]) -> int:
        """
        https://doc.qt.io/qt-6/qdatetime.html#msecsTo

        **qint64 QDateTime::msecsTo(const QDateTime & other ) const**

        Returns the number of milliseconds from this datetime to the **other**
        datetime. If the **other** datetime is earlier than this datetime, the
        value returned is negative.

        Before performing the comparison, the two datetimes are converted to
        **Qt::UTC**  to ensure that the result is correct if daylight-saving
        (DST) applies to one of the two datetimes and but not the other.

        Returns 0 if either datetime is invalid.

        **See also** **addMSecs** (), **daysTo** (), and **QTime::msecsTo** ().
        """
        ...

    def setMSecsSinceEpoch(self, msecs: int) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#setMSecsSinceEpoch

        **void QDateTime::setMSecsSinceEpoch(qint64 msecs )**

        Sets the date and time given the number of milliseconds **msecs** that
        have passed since 1970-01-01T00:00:00.000, Coordinated Universal Time
        (**Qt::UTC** ). On systems that do not support time zones this function
        will behave as if local time were **Qt::UTC** .

        Note that passing the minimum of `qint64`
        (`std::numeric_limits<qint64>::min()`) to **msecs** will result in
        undefined behavior.

        **See also** **toMSecsSinceEpoch** () and **setSecsSinceEpoch** ().
        """
        ...

    def toMSecsSinceEpoch(self) -> int:
        """
        https://doc.qt.io/qt-6/qdatetime.html#toMSecsSinceEpoch

        **qint64 QDateTime::toMSecsSinceEpoch() const**

        Returns the datetime as the number of milliseconds that have passed
        since 1970-01-01T00:00:00.000, Coordinated Universal Time (**Qt::UTC**
        ).

        On systems that do not support time zones, this function will behave as
        if local time were **Qt::UTC** .

        The behavior for this function is undefined if the datetime stored in
        this object is not valid. However, for all valid dates, this function
        returns a unique value.

        **See also** **toSecsSinceEpoch** () and **setMSecsSinceEpoch** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromString(string: str, format: Qt.DateFormat = ...) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#fromString

        **[static] QDateTime QDateTime::fromString(const QString & string ,
        Qt::DateFormat format = Qt::TextDate)**

        Returns the **QDateTime**  represented by the **string** , using the
        **format** given, or an invalid datetime if this is not possible.

        Note for **Qt::TextDate** : only English short month names (e.g. "Jan"
        in short form or "January" in long form) are recognized.

        **See also** **toString** () and **QLocale::toDateTime** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromString(string: str, format: str, cal: QCalendar = ...) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#fromString-1

        **[static, since 6.0] QDateTime QDateTime::fromString(QStringView string
        , Qt::DateFormat format = Qt::TextDate)**

        This is an overloaded function.

        This function was introduced in Qt 6.0.
        """
        ...

    @staticmethod
    def currentDateTime() -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#currentDateTime

        **[static] QDateTime QDateTime::currentDateTime()**

        Returns the current datetime, as reported by the system clock, in the
        local time zone.

        **See also** **currentDateTimeUtc** (), **QDate::currentDate** (),
        **QTime::currentTime** (), and **toTimeSpec** ().
        """
        ...

    def secsTo(self, a0: typing.Union["QDateTime", datetime.datetime]) -> int:
        """
        https://doc.qt.io/qt-6/qdatetime.html#secsTo

        **qint64 QDateTime::secsTo(const QDateTime & other ) const**

        Returns the number of seconds from this datetime to the **other**
        datetime. If the **other** datetime is earlier than this datetime, the
        value returned is negative.

        Before performing the comparison, the two datetimes are converted to
        **Qt::UTC**  to ensure that the result is correct if daylight-saving
        (DST) applies to one of the two datetimes but not the other.

        Returns 0 if either datetime is invalid.

        Example:

        **QDateTime**  now = **QDateTime** ::currentDateTime();
        **QDateTime**  xmas(**QDate** (now.date().year(), 12, 25).startOfDay());
        **qDebug** ("There are %d seconds to Christmas", now.secsTo(xmas));

        **See also** **addSecs** (), **daysTo** (), and **QTime::secsTo** ().
        """
        ...

    def daysTo(self, a0: typing.Union["QDateTime", datetime.datetime]) -> int:
        """
        https://doc.qt.io/qt-6/qdatetime.html#daysTo

        **qint64 QDateTime::daysTo(const QDateTime & other ) const**

        Returns the number of days from this datetime to the **other** datetime.
        The number of days is counted as the number of times midnight is reached
        between this datetime to the **other** datetime. This means that a 10
        minute difference from 23:55 to 0:05 the next day counts as one day.

        If the **other** datetime is earlier than this datetime, the value
        returned is negative.

        Example:

        **QDateTime**  startDate(**QDate** (2012, 7, 6), **QTime** (8, 30, 0));
        **QDateTime**  endDate(**QDate** (2012, 7, 7), **QTime** (16, 30, 0));
        **qDebug** () << "Days from startDate to endDate: " <<
        startDate.daysTo(endDate);

            startDate = **QDateTime** (**QDate**
        (2012, 7, 6), **QTime** (23, 55, 0));
            endDate = **QDateTime**
        (**QDate** (2012, 7, 7), **QTime** (0, 5, 0));
            **qDebug** () <<
        "Days from startDate to endDate: " << startDate.daysTo(endDate);
        qSwap(startDate, endDate); // Make endDate before startDate.
        **qDebug** () << "Days from startDate to endDate: " <<
        startDate.daysTo(endDate);

        **See also** **addDays** (), **secsTo** (), and **msecsTo** ().
        """
        ...

    def toUTC(self) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#toUTC

        **QDateTime QDateTime::toUTC() const**

        Returns a datetime containing the date and time information in this
        datetime, but specified using the **Qt::UTC**  definition.

        Example:

        **QDateTime**  local(**QDateTime** ::currentDateTime());
        **QDateTime**  UTC(local.toUTC());
            **qDebug** () << "Local time is:"
        << local;
            **qDebug** () << "UTC time is:" << UTC;
            **qDebug** ()
        << "No difference between times:" << local.secsTo(UTC);

        **See also** **toTimeSpec** ().
        """
        ...

    def toLocalTime(self) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#toLocalTime

        **QDateTime QDateTime::toLocalTime() const**

        Returns a datetime containing the date and time information in this
        datetime, but specified using the **Qt::LocalTime**  definition.

        Example:

        **QDateTime**  UTC(**QDateTime** ::currentDateTimeUtc());
        **QDateTime**  local(UTC.toLocalTime());
            **qDebug** () << "UTC time
        is:" << UTC;
            **qDebug** () << "Local time is:" << local;
        **qDebug** () << "No difference between times:" << UTC.secsTo(local);

        **See also** **toTimeSpec** ().
        """
        ...

    def toTimeSpec(self, spec: Qt.TimeSpec) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#toTimeSpec

        **QDateTime QDateTime::toTimeSpec(Qt::TimeSpec spec ) const**

        Returns a copy of this datetime converted to the given time **spec**.

        If **spec** is **Qt::OffsetFromUTC**  then it is set to **Qt::UTC** . To
        set to a spec of **Qt::OffsetFromUTC**  use **toOffsetFromUtc** ().

        If **spec** is **Qt::TimeZone**  then it is set to **Qt::LocalTime** ,
        i.e. the local Time Zone.

        Example:

        **QDateTime**  local(**QDateTime** ::currentDateTime());
        **QDateTime**  UTC(local.toTimeSpec(Qt::UTC));
            **qDebug** () <<
        "Local time is:" << local;
            **qDebug** () << "UTC time is:" << UTC;
        **qDebug** () << "No difference between times:" << local.secsTo(UTC);

        **See also** **timeSpec** (), **toTimeZone** (), and **toOffsetFromUtc**
        ().
        """
        ...

    def addMSecs(self, msecs: int) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#addMSecs

        **QDateTime QDateTime::addMSecs(qint64 msecs ) const**

        Returns a **QDateTime**  object containing a datetime **msecs**
        milliseconds later than the datetime of this object (or earlier if
        **msecs** is negative).

        If this datetime is invalid, an invalid datetime will be returned.

        **See also** **addSecs** (), **msecsTo** (), **addDays** (),
        **addMonths** (), and **addYears** ().
        """
        ...

    def addSecs(self, secs: int) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#addSecs

        **QDateTime QDateTime::addSecs(qint64 s ) const**

        Returns a **QDateTime**  object containing a datetime **s** seconds
        later than the datetime of this object (or earlier if **s** is
        negative).

        If this datetime is invalid, an invalid datetime will be returned.

        **See also** **addMSecs** (), **secsTo** (), **addDays** (),
        **addMonths** (), and **addYears** ().
        """
        ...

    def addYears(self, years: int) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#addYears

        **QDateTime QDateTime::addYears(int nyears ) const**

        Returns a **QDateTime**  object containing a datetime **nyears** years
        later than the datetime of this object (or earlier if **nyears** is
        negative).

        If the **timeSpec** () is **Qt::LocalTime**  or **Qt::TimeZone**  and
        the resulting date and time fall in the Standard Time to Daylight-Saving
        Time transition hour then the result will be adjusted accordingly, i.e.
        if the transition is at 2am and the clock goes forward to 3am and the
        result falls between 2am and 3am then the result will be adjusted to
        fall after 3am.

        **See also** **daysTo** (), **addDays** (), **addMonths** (), and
        **addSecs** ().
        """
        ...

    def addMonths(self, months: int) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#addMonths

        **QDateTime QDateTime::addMonths(int nmonths ) const**

        Returns a **QDateTime**  object containing a datetime **nmonths** months
        later than the datetime of this object (or earlier if **nmonths** is
        negative).

        If the **timeSpec** () is **Qt::LocalTime**  or **Qt::TimeZone**  and
        the resulting date and time fall in the Standard Time to Daylight-Saving
        Time transition hour then the result will be adjusted accordingly, i.e.
        if the transition is at 2am and the clock goes forward to 3am and the
        result falls between 2am and 3am then the result will be adjusted to
        fall after 3am.

        **See also** **daysTo** (), **addDays** (), **addYears** (), and
        **addSecs** ().
        """
        ...

    def addDays(self, days: int) -> "QDateTime":
        """
        https://doc.qt.io/qt-6/qdatetime.html#addDays

        **QDateTime QDateTime::addDays(qint64 ndays ) const**

        Returns a **QDateTime**  object containing a datetime **ndays** days
        later than the datetime of this object (or earlier if **ndays** is
        negative).

        If the **timeSpec** () is **Qt::LocalTime**  or **Qt::TimeZone**  and
        the resulting date and time fall in the Standard Time to Daylight-Saving
        Time transition hour then the result will be adjusted accordingly, i.e.
        if the transition is at 2am and the clock goes forward to 3am and the
        result falls between 2am and 3am then the result will be adjusted to
        fall after 3am.

        **See also** **daysTo** (), **addMonths** (), **addYears** (), and
        **addSecs** ().
        """
        ...

    @typing.overload
    def toString(self, format: Qt.DateFormat = ...) -> str:
        """
        https://doc.qt.io/qt-6/qdatetime.html#toString-1

        **QString QDateTime::toString(Qt::DateFormat format = Qt::TextDate)
        const**

        This is an overloaded function.

        Returns the datetime as a string in the **format** given.

        If the **format** is **Qt::TextDate** , the string is formatted in the
        default way. The day and month names will be in English. An example of
        this formatting is "Wed May 20 03:40:13 1998". For localized formatting,
        see **QLocale::toString** ().

        If the **format** is **Qt::ISODate** , the string format corresponds to
        the ISO 8601 extended specification for representations of dates and
        times, taking the form yyyy-MM-ddTHH:mm:ss[Z|[+|-]HH:mm], depending on
        the **timeSpec** () of the **QDateTime** . If the **timeSpec** () is
        **Qt::UTC** , Z will be appended to the string; if the **timeSpec** ()
        is **Qt::OffsetFromUTC** , the offset in hours and minutes from UTC will
        be appended to the string. To include milliseconds in the ISO 8601 date,
        use the **format** **Qt::ISODateWithMs** , which corresponds to yyyy-MM-
        ddTHH:mm:ss.zzz[Z|[+|-]HH:mm].

        If the **format** is **Qt::RFC2822Date** , the string is formatted
        following **RFC 2822** .

        If the datetime is invalid, an empty string will be returned.

        **Warning:** The **Qt::ISODate**  format is only valid for years in the
        range 0 to 9999.

        **See also** **fromString** (), **QDate::toString** (),
        **QTime::toString** (), and **QLocale::toString** ().
        """
        ...

    @typing.overload
    def toString(self, format: str, cal: QCalendar = ...) -> str:
        """
        https://doc.qt.io/qt-6/qdatetime.html#toString-1

        **QString QDateTime::toString(Qt::DateFormat format = Qt::TextDate)
        const**

        This is an overloaded function.

        Returns the datetime as a string in the **format** given.

        If the **format** is **Qt::TextDate** , the string is formatted in the
        default way. The day and month names will be in English. An example of
        this formatting is "Wed May 20 03:40:13 1998". For localized formatting,
        see **QLocale::toString** ().

        If the **format** is **Qt::ISODate** , the string format corresponds to
        the ISO 8601 extended specification for representations of dates and
        times, taking the form yyyy-MM-ddTHH:mm:ss[Z|[+|-]HH:mm], depending on
        the **timeSpec** () of the **QDateTime** . If the **timeSpec** () is
        **Qt::UTC** , Z will be appended to the string; if the **timeSpec** ()
        is **Qt::OffsetFromUTC** , the offset in hours and minutes from UTC will
        be appended to the string. To include milliseconds in the ISO 8601 date,
        use the **format** **Qt::ISODateWithMs** , which corresponds to yyyy-MM-
        ddTHH:mm:ss.zzz[Z|[+|-]HH:mm].

        If the **format** is **Qt::RFC2822Date** , the string is formatted
        following **RFC 2822** .

        If the datetime is invalid, an empty string will be returned.

        **Warning:** The **Qt::ISODate**  format is only valid for years in the
        range 0 to 9999.

        **See also** **fromString** (), **QDate::toString** (),
        **QTime::toString** (), and **QLocale::toString** ().
        """
        ...

    def setTimeSpec(self, spec: Qt.TimeSpec) -> None:
        """
        https://doc.qt.io/qt-6/qdatetime.html#setTimeSpec

        **void QDateTime::setTimeSpec(Qt::TimeSpec spec )**

        Sets the time specification used in this datetime to **spec**. The
        datetime will refer to a different point in time.

        If **spec** is **Qt::OffsetFromUTC**  then the **timeSpec** () will be
        set to **Qt::UTC** , i.e. an effective offset of 0.

        If **spec** is **Qt::TimeZone**  then the spec will be set to
        **Qt::LocalTime** , i.e. the current system time zone.

        Example:

        **QDateTime**  local(**QDateTime** ::currentDateTime());
            **qDebug**
        () << "Local time is:" << local;

            **QDateTime**  UTC(local);
        UTC.setTimeSpec(Qt::UTC);
            **qDebug** () << "UTC time is:" << UTC;
        **qDebug** () << "There are" << local.secsTo(UTC) << "seconds difference
        between the datetimes.";

        **See also** **timeSpec** (), **setDate** (), **setTime** (),
        **setTimeZone** (), and **Qt::TimeSpec** .
        """
        ...

    def timeSpec(self) -> Qt.TimeSpec:
        """
        https://doc.qt.io/qt-6/qdatetime.html#timeSpec

        **Qt::TimeSpec QDateTime::timeSpec() const**

        Returns the time specification of the datetime.

        **See also** **setTimeSpec** (), **date** (), **time** (), and
        **Qt::TimeSpec** .
        """
        ...

    def time(self) -> QTime:
        """
        https://doc.qt.io/qt-6/qdatetime.html#time

        **QTime QDateTime::time() const**

        Returns the time part of the datetime.

        **See also** **setTime** (), **date** (), and **timeSpec** ().
        """
        ...

    def date(self) -> QDate:
        """
        https://doc.qt.io/qt-6/qdatetime.html#date

        **QDate QDateTime::date() const**

        Returns the date part of the datetime.

        **See also** **setDate** (), **time** (), and **timeSpec** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdatetime.html#isValid

        **bool QDateTime::isValid() const**

        Returns `true` if both the date and the time are valid and they are
        valid in the current **Qt::TimeSpec** , otherwise returns `false`.

        If the **timeSpec** () is **Qt::LocalTime**  or **Qt::TimeZone**  and
        this object represents a time that was skipped by a forward transition,
        then it is invalid. For example, if DST ends at 2am with the clock
        advancing to 3am, then date-times from 02:00:00 to 02:59:59.999 on that
        day are considered invalid.

        **See also** **QDateTime::YearRange** , **QDate::isValid** (), and
        **QTime::isValid** ().
        """
        ...

    def __bool__(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdatetime.html#isNull

        **bool QDateTime::isNull() const**

        Returns `true` if both the date and the time are null; otherwise returns
        `false`. A null datetime is invalid.

        **See also** **QDate::isNull** (), **QTime::isNull** (), and **isValid**
        ().
        """
        ...

    def toPyDateTime(self) -> datetime.datetime:
        ...

    def __hash__(self) -> int:
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QSaveFile(QFileDevice):
    """
    https://doc.qt.io/qt-6/qsavefile.html

    **Detailed Description**

    QSaveFile is an I/O device for writing text and binary files, without losing
    existing data if the writing operation fails.

    While writing, the contents will be written to a temporary file, and if no
    error happened, **commit** () will move it to the final file. This ensures
    that no data at the final file is lost in case an error happens while
    writing, and no partially-written file is ever present at the final
    location. Always use QSaveFile when saving entire documents to disk.

    QSaveFile automatically detects errors while writing, such as the full
    partition situation, where **write** () cannot write all the bytes. It will
    remember that an error happened, and will discard the temporary file in
    **commit** ().

    Much like with **QFile** , the file is opened with **open** (). Data is
    usually read and written using **QDataStream**  or **QTextStream** , but you
    can also call the **QIODevice** -inherited functions **read** (),
    **readLine** (), **readAll** (), **write** ().

    Unlike **QFile** , calling **close** () is not allowed. **commit** ()
    replaces it. If **commit** () was not called and the QSaveFile instance is
    destroyed, the temporary file is discarded.

    To abort saving due to an application error, call **cancelWriting** (), so
    that even a call to **commit** () later on will not save.

    **See also** **QTextStream** , **QDataStream** , **QFileInfo** , **QDir** ,
    **QFile** , and **QTemporaryFile** .
    """

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qsavefile.html#QSaveFile

        **QSaveFile::QSaveFile(const QString & name )**

        Constructs a new file object to represent the file with the given
        **name**.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsavefile.html#QSaveFile-1

        **QSaveFile::QSaveFile(QObject * parent = nullptr)**

        Constructs a new file object with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(self, name: str, parent: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qsavefile.html#QSaveFile-2

        **QSaveFile::QSaveFile(const QString & name , QObject * parent )**

        Constructs a new file object with the given **parent** to represent the
        file with the specified **name**.
        """
        ...

    def writeData(self, a0: PyQt6.sip.Buffer) -> int:
        """
        https://doc.qt.io/qt-6/qsavefile.html#writeData

        **[override virtual protected] qint64 QSaveFile::writeData(const char *
        data , qint64 len )**

        Reimplements: **QFileDevice::writeData** (const char *data, qint64 len).
        """
        ...

    def directWriteFallback(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsavefile.html#directWriteFallback

        **bool QSaveFile::directWriteFallback() const**

        Returns `true` if the fallback solution for saving files in read-only
        directories is enabled.

        **See also** **setDirectWriteFallback** ().
        """
        ...

    def setDirectWriteFallback(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsavefile.html#setDirectWriteFallback

        **void QSaveFile::setDirectWriteFallback(bool enabled )**

        Allows writing over the existing file if necessary.

        **QSaveFile**  creates a temporary file in the same directory as the
        final file and atomically renames it. However this is not possible if
        the directory permissions do not allow creating new files. In order to
        preserve atomicity guarantees, **open** () fails when it cannot create
        the temporary file.

        In order to allow users to edit files with write permissions in a
        directory with restricted permissions, call setDirectWriteFallback()
        with **enabled** set to true, and the following calls to **open** ()
        will fallback to opening the existing file directly and writing into it,
        without the use of a temporary file. This does not have atomicity
        guarantees, i.e. an application crash or for instance a power failure
        could lead to a partially-written file on disk. It also means
        **cancelWriting** () has no effect, in such a case.

        Typically, to save documents edited by the user, call
        setDirectWriteFallback(true), and to save application internal files
        (configuration files, data files, ...), keep the default setting which
        ensures atomicity.

        **See also** **directWriteFallback** ().
        """
        ...

    def cancelWriting(self) -> None:
        """
        https://doc.qt.io/qt-6/qsavefile.html#cancelWriting

        **void QSaveFile::cancelWriting()**

        Cancels writing the new file.

        If the application changes its mind while saving, it can call
        cancelWriting(), which sets an error code so that **commit** () will
        discard the temporary file.

        Alternatively, it can simply make sure not to call **commit** ().

        Further write operations are possible after calling this method, but
        none of it will have any effect, the written file will be discarded.

        This method has no effect when direct write fallback is used. This is
        the case when saving over an existing file in a readonly directory: no
        temporary file can be created, so the existing file is overwritten no
        matter what, and cancelWriting() cannot do anything about that, the
        contents of the existing file will be lost.

        **See also** **commit** ().
        """
        ...

    def commit(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsavefile.html#commit

        **bool QSaveFile::commit()**

        Commits the changes to disk, if all previous writes were successful.

        It is mandatory to call this at the end of the saving operation,
        otherwise the file will be discarded.

        If an error happened during writing, deletes the temporary file and
        returns `false`. Otherwise, renames it to the final **fileName**  and
        returns `true` on success. Finally, closes the device.

        **See also** **cancelWriting** ().
        """
        ...

    def open(self, flags: QIODeviceBase.OpenModeFlag) -> bool:
        """
        https://doc.qt.io/qt-6/qsavefile.html#open

        **[override virtual] bool QSaveFile::open(QIODeviceBase::OpenMode mode
        )**

        Reimplements: **QIODevice::open** (QIODeviceBase::OpenMode mode).

        Opens the file using OpenMode **mode** , returning true if successful;
        otherwise false.

        Important: the **mode** must include QIODevice::WriteOnly. It may also
        have additional flags, such as QIODevice::Text and
        QIODevice::Unbuffered.

        QIODevice::ReadWrite, QIODevice::Append, QIODevice::NewOnly and
        QIODevice::ExistingOnly are not supported at the moment.

        **See also** **QIODevice::OpenMode**  and **setFileName** ().
        """
        ...

    def setFileName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qsavefile.html#setFileName

        **void QSaveFile::setFileName(const QString & name )**

        Sets the **name** of the file. The name can have no path, a relative
        path, or an absolute path.

        **See also** **QFile::setFileName** () and **fileName** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsavefile.html#fileName

        **[override virtual] QString QSaveFile::fileName() const**

        Reimplements: **QFileDevice::fileName() const** .

        Returns the name set by **setFileName** () or to the **QSaveFile**
        constructor.

        **See also** **setFileName** ().
        """
        ...
